/*    patchlevel.h
 *
 *    Copyright (C) 1993, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
 *    2003, 2004, 2005, 2006, 2007, 2008, 2009, by Larry Wall and others
 *
 *    You may distribute under the terms of either the GNU General Public
 *    License or the Artistic License, as specified in the README file.
 *
 */

#ifndef __PATCHLEVEL_H_INCLUDED__

/* do not adjust the whitespace! Configure expects the numbers to be
 * exactly on the third column */

#define PERL_REVISION	5		/* age */
#define PERL_VERSION	32		/* epoch */
#define PERL_SUBVERSION	1		/* generation */

/* The following numbers describe the earliest compatible version of
   Perl ("compatibility" here being defined as sufficient binary/API
   compatibility to run XS code built with the older version).
   Normally this should not change across maintenance releases.

   Note that this only refers to an out-of-the-box build.  Many non-default
   options such as usemultiplicity tend to break binary compatibility
   more often.

   This is used by Configure et al to figure out
   PERL_INC_VERSION_LIST, which lists version libraries
   to include in @INC.  See INSTALL for how this works.

   Porting/bump-perl-version will automatically set these to the version of perl
   to be released for blead releases, and to 5.X.0 for maint releases. Manually
   changing them should not be necessary.
*/
#define PERL_API_REVISION	5
#define PERL_API_VERSION	32
#define PERL_API_SUBVERSION	0
/*
   XXX Note:  The selection of non-default Configure options, such
   as -Duselonglong may invalidate these settings.  Currently, Configure
   does not adequately test for this.   A.D.  Jan 13, 2000
*/

#define __PATCHLEVEL_H_INCLUDED__
#endif

/*
	local_patches -- list of locally applied less-than-subversion patches.
	If you're distributing such a patch, please give it a name and a
	one-line description, placed just before the last NULL in the array
	below.  If your patch fixes a bug in the perlbug database, please
	mention the bugid.  If your patch *IS* dependent on a prior patch,
	please place your applied patch line after its dependencies. This
	will help tracking of patch dependencies.

	Please either use 'diff --unified=0' if your diff supports
	that or edit the hunk of the diff output which adds your patch
	to this list, to remove context lines which would give patch
	problems. For instance, if the original context diff is

	   *** patchlevel.h.orig	<date here>
	   --- patchlevel.h	<date here>
	   *** 38,43 ***
	   --- 38,44 ---
	     	,"FOO1235 - some patch"
	     	,"BAR3141 - another patch"
	     	,"BAZ2718 - and another patch"
	   + 	,"MINE001 - my new patch"
	     	,NULL
	     };

	please change it to
	   *** patchlevel.h.orig	<date here>
	   --- patchlevel.h	<date here>
	   *** 41,43 ***
	   --- 41,44 ---
	   + 	,"MINE001 - my new patch"
	     	,NULL
	     };

	(Note changes to line numbers as well as removal of context lines.)
	This will prevent patch from choking if someone has previously
	applied different patches than you.

        History has shown that nobody distributes patches that also
        modify patchlevel.h. Do it yourself. The following perl
        program can be used to add a comment to patchlevel.h:

#!perl
die "Usage: perl -x patchlevel.h comment ..." unless @ARGV;
open PLIN, "<", "patchlevel.h" or die "Couldn't open patchlevel.h : $!";
open PLOUT, ">", "patchlevel.new" or die "Couldn't write on patchlevel.new : $!";
my $seen=0;
while (<PLIN>) {
    if (/\t,NULL/ and $seen) {
       while (my $c = shift @ARGV){
	    $c =~ s|\\|\\\\|g;
	    $c =~ s|"|\\"|g;
            print PLOUT qq{\t,"$c"\n};
       }
    }
    $seen++ if /local_patches\[\]/;
    print PLOUT;
}
close PLOUT or die "Couldn't close filehandle writing to patchlevel.new : $!";
close PLIN or die "Couldn't close filehandle reading from patchlevel.h : $!";
close DATA; # needed to allow unlink to work win32.
unlink "patchlevel.bak" or warn "Couldn't unlink patchlevel.bak : $!"
  if -e "patchlevel.bak";
rename "patchlevel.h", "patchlevel.bak" or
  die "Couldn't rename patchlevel.h to patchlevel.bak : $!";
rename "patchlevel.new", "patchlevel.h" or
  die "Couldn't rename patchlevel.new to patchlevel.h : $!";
__END__

Please keep empty lines below so that context diffs of this file do
not ever collect the lines belonging to local_patches() into the same
hunk.

 */

#if !defined(PERL_PATCHLEVEL_H_IMPLICIT) && !defined(LOCAL_PATCH_COUNT)
#  if defined(PERL_IS_MINIPERL)
#    define PERL_PATCHNUM "UNKNOWN-miniperl"
#    define PERL_GIT_UNPUSHED_COMMITS /*leave-this-comment*/
#  elif defined(PERL_MICRO)
#    define PERL_PATCHNUM "UNKNOWN-microperl"
#    define PERL_GIT_UNPUSHED_COMMITS /*leave-this-comment*/
#  else
#include "git_version.h"
#  endif
static const char * const local_patches[] = {
	NULL
#ifdef PERL_GIT_UNCOMMITTED_CHANGES
	,"uncommitted-changes"
#endif
	PERL_GIT_UNPUSHED_COMMITS    	/* do not remove this line */
	,"Fedora Patch1: Removes date check, Fedora/RHEL specific"
	,"Fedora Patch2: support for libdir64"
	,"Fedora Patch3: use libresolv instead of libbind"
	,"Fedora Patch4: USE_MM_LD_RUN_PATH"
	,"Fedora Patch5: Provide MM::maybe_command independently (bug #1129443)"
	,"Fedora Patch6: Dont run one io test due to random builder failures"
	,"Fedora Patch8: Define SONAME for libperl.so"
	,"Fedora Patch9: Install libperl.so to -Dshrpdir value"
	,"Fedora Patch10: Make *DBM_File desctructors thread-safe (RT#61912)"
	,"Fedora Patch11: Replace EU::MakeMaker dependency with EU::MM::Utils in IPC::Cmd (bug #1129443)"
	,"Fedora Patch12: Link XS modules to pthread library to fix linking with -z defs"
	,"Fedora Patch13: Pass the correct CFLAGS to dtrace"
	,"Fedora Patch14: Do not use C compiler reserved identifiers"
	,"Fedora Patch15: Fix SvUV_nomg() macro definition"
	,"Fedora Patch16: Fix SvTRUE() documentation"
	,"Fedora Patch17: Fix ext/XS-APItest/t/utf8_warn_base.pl tests"
	,"Fedora Patch18: Fix IO::Handle::error() to report write errors (GH#6799)"
	,"Fedora Patch19: Fix IO::Handle::error() to report write errors (GH#6799)"
	,"Fedora Patch21: Fix setting a non-blocking mode in IO::Socket::UNIX (GH#17787)"
	,"Fedora Patch22: Fix running actions after stepping in a debugger (GH#17901)"
	,"Fedora Patch23: Fix running actions after stepping in a debugger (GH#17901)"
	,"Fedora Patch24: Fix running actions after stepping in a debugger (GH#17901)"
	,"Fedora Patch25: Fix a buffer size for asctime_r() and ctime_r() functions"
	,"Fedora Patch26: Prevent from an integer overflow in RenewDouble() macro"
	,"Fedora Patch28: Fix a number of arguments passed to a BOOT XS subroutine (GH#17755)"
	,"Fedora Patch29: Fix an IO::Handle spurious error reported for regular file handles (GH#18019)"
	,"Fedora Patch30: Fix inheritance resolution of lexial objects in a debugger (GH#17661)"
	,"Fedora Patch35: Fix sorting with a block that calls return (GH#18081)"
	,"Fedora Patch38: Fix sv_collxfrm macro to respect locale"
	,"Fedora Patch39: Fix an iterator signedness in handling an mro exception (GH#18155)"
	,"Fedora Patch40: Fix a code flow in Perl_sv_inc_nomg()"
	,"Fedora Patch41: Fix an undefined behavior in Perl_custom_op_get_field()"
	,"Fedora Patch42: Fix Config variable names in in t/op tests"
	,"Fedora Patch43: Fix fetching a magic on the stacked file test operators"
	,"Fedora Patch44: Fix a crash in optimizing split() (GH#18232)"
	,"Fedora Patch45: Fix a crash in optimizing split() (GH#18232)"
	,"Fedora Patch46: Fix a crash in optimizing split() (GH#18232)"
	,"Fedora Patch47: Fix a crash in optimizing split() (GH#18232)"
	,"Fedora Patch48: Make accessing environment by DynaLoader thread-safe"
	,"Fedora Patch49: Use duplocale() if available"
	,"Fedora Patch50: Fix fc() in Turkish locale"
	,"Fedora Patch51: Fix croaking on \"my $_\" when \"use utf8\" is in effect (GH#18449)"
	,"Fedora Patch52: Fix PERL_UNUSED_ARG() definition in XSUB.h"
	,"Fedora Patch53: Add missing entries to perldiag (GH#18276)"
	,"Fedora Patch54: Protect locale tests from LANGUAGE environment variable"
	,"Fedora Patch55: Prevent the number of buckets in a hash from getting too large"
	,"Fedora Patch56: Fix a memory leak when compiling a regular expression (GH#18604)"
	,"Fedora Patch200: Link XS modules to libperl.so with EU::CBuilder on Linux"
	,"Fedora Patch201: Link XS modules to libperl.so with EU::MM on Linux"
	,NULL
};



/* Initial space prevents this variable from being inserted in config.sh  */
#  define	LOCAL_PATCH_COUNT	\
	((int)(C_ARRAY_LENGTH(local_patches)-2))

/* the old terms of reference, add them only when explicitly included */
#define PATCHLEVEL		PERL_VERSION
#undef  SUBVERSION		/* OS/390 has a SUBVERSION in a system header */
#define SUBVERSION		PERL_SUBVERSION
#endif
